library(gplots)

a <- load("data/ucec_ge.RData")
ge <- ucec_ge
a <- load("data/ucec_annotation.RData")
a <- load("data/signatures_gatza.RData")

dim(ucec_ge)

signatures_acidosis <- unlist(signatures_gatza["ACIDOSIS"])

acidosis_ge <- ge[signatures_acidosis,]

ac_ge_log <- log2(acidosis_ge+1)

ac_ge_st <- t(apply(ac_ge_log,1,function(x) (x - mean(x))/sd(x)))

gene_clust = hclust(dist(ac_ge_st, method='euclidean'), method = 'complete')
sample_clust = hclust(dist(t(ac_ge_st), method='euclidean'), method = 'complete')

pdf('output/1_heatmap_acidosis.pdf', width=8, height=8)
heatmap.2(ac_ge_st, trace = "none",
          Rowv = as.dendrogram(gene_clust),
          Colv = as.dendrogram(sample_clust),
          col=colorRampPalette(c('blue', 'white', 'red')),
          main = "Acidodis, ucec, 3color",
          margins = c(2,8))
dev.off()

ac_ge_st_mn <- apply(ac_ge_st,2,mean)

subtyping <- droplevels(as.factor(ucec_annotation[names(ucec_annotation) %in% names(ac_ge_st_mn)]))

ac_ge_st_mn <- ac_ge_st_mn[names(ac_ge_st_mn) %in% names(ucec_annotation)]

boxplot(ac_ge_st_mn~subtyping_ac)

ges_tot <- matrix(0L, nrow = 49, ncol = 304)

rownames(ges_tot) <- names(signatures_gatza)

for (id in names(signatures_gatza)) {
  signatures_id <- unlist(signatures_gatza[[id]])
  
  signatures_id <- signatures_id[signatures_id %in% rownames(ge)]
  
  id_ge <- ge[signatures_id,]
  
  id_ge_log <- log2(id_ge+1)
  
  id_ge_st <- t(apply(id_ge_log,1,function(x) (x - mean(x))/sd(x)))
  
  id_ge_st_mn <- apply(id_ge_st,2,mean)

  id_ge_st_mn <- id_ge_st_mn[names(id_ge_st_mn) %in% names(ucec_annotation)]
  
  ges_tot[id,] <- id_ge_st_mn

}

colnames(ges_tot) <- names(ac_ge_st_mn)

gene_clust = hclust(dist(ges_tot, method='euclidean'), method = 'complete')
sample_clust = hclust(dist(t(ges_tot), method='euclidean'), method = 'complete')

pdf('output/2_heatmap_signatures.pdf', width=8, height=8)
heatmap.2(ges_tot, trace = "none",
          Rowv = as.dendrogram(gene_clust),
          Colv = as.dendrogram(sample_clust),
          col=colorRampPalette(c('blue', 'white', 'red')),
          main = "ucec, sig, 3color",
          margins = c(2,16))
dev.off()

subtypes <- sort(levels(subtyping))

subtype_color_scale = c('red', 'green', 'blue')
names(subtype_color_scale) = subtypes

table(subtyping)

names(subtyping) == colnames(ges_tot)

subtype_colors = subtype_color_scale[subtyping]
names(subtype_colors) = names(subtyping)
print(subtype_color_scale)

pdf('output/3_heatmap_signatures_subtype.pdf', width=8, height=8)
heatmap.2(ges_tot[, order(subtyping)],
          trace='none',
          col=colorRampPalette(c('blue', 'white', 'red')),
          ColSideColors=subtype_colors[order(subtyping)],
          Colv = FALSE,
          dendrogram = 'row',
          Rowv = as.dendrogram(gene_clust),
          labCol = paste(unlist(names(subtype_color_scale)), collapse = "         "),
          cexCol = 1.1,
          srtCol = 0,
          margins = c(2,16),
          adjCol = c(0,-64.5),
          main = "UCEC, 3color, sig, by subtype")
dev.off()

al = aov(ges_tot[1,] ~ subtyping[names(ges_tot[1,])])
pairwise.t.test(ges_tot[1,], subtyping[names(ges_tot[1,])])
TukeyHSD(al)

p.difference <- matrix(0L, nrow = 49, ncol = 3)

rownames(p.difference) <- row.names(ges_tot)

for (signature in row.names(ges_tot)){
  al = aov(ges_tot[signature,] ~ subtyping[names(ges_tot[signature,])])
  tukey <- TukeyHSD(al)
  tukey.result <- data.frame(TukeyHSD(al)$subtyping)
  p.values <- tukey.result$p.adj
  p.difference[signature,] <- p.values
}

colnames(p.difference) <- c("CN_LOW - CN_HIGH", "MSI - CN_HIGH", "MSI - CN_LOW")

pdf('output/4_heatmap_stats.pdf', width=8, height=10)
heatmap.2(p.difference,
          trace='none',
          Colv = FALSE,
          dendrogram = 'row',
          Rowv = as.dendrogram(gene_clust),
          breaks = c(0.00,0.001,0.01,0.05,1), col=colorRampPalette(c('black', 'dark grey', "light grey", "white")),
          colsep=1:ncol(p.difference),
          rowsep=1:nrow(p.difference),
          sepcolor="black",
          sepwidth=c(0.001,0.001),
          cexCol = 0.75,
          srtCol = 0,
          margins = c(10,16),
          adjCol = c(0.5,-83),
          key = FALSE,
          main = "UCEC, p values")
par(lend = 1) 
legend("bottomright",
       legend = c("p < 0.001", "p < 0.01", "p < 0.05", "NS"),
       fill = c("black", "dark grey", "light grey", "white"),
       border = "black",
       ncol = 4)
dev.off()

ges_mean <- apply(ges_tot,2,mean)
boxplot(ges_mean~subtyping)

          